import inspect


def call_func(f_callable, only_mandatory=False, **kwargs):
    """Calls a function with the given parameters given in kwargs if they
    exist as parameters in f_callable.

    Parameters
    ----------
    f_callable : callable
        The function or object that is to be called
    only_mandatory : boolean
        If True only mandatory parameters are set.
    kwargs : kwargs
        All parameters that could be used for calling f_callable.

    Returns
    -------
    called object
    """
    params = inspect.signature(f_callable).parameters
    param_keys = params.keys()
    if only_mandatory:
        param_keys = list(
            filter(lambda k: params[k].default == inspect._empty, param_keys)
        )

    vars = dict(filter(lambda e: e[0] in param_keys, kwargs.items()))

    return f_callable(**vars)


def _available_if(method_name, has_available_if):
    if has_available_if:
        from sklearn.utils.metaestimators import available_if

        decorator = available_if(
            lambda self: hasattr(self.estimator, method_name)
        )
    else:
        from sklearn.utils.metaestimators import if_delegate_has_method

        decorator = if_delegate_has_method(delegate="estimator")
    return decorator
